View Source EctoAnon.Schema (ecto_anon v0.6.0)
EctoAnon.Schema lets you define anonymizable fields.
Summary
Functions
Macro to declare anonymizable fields
Macro to create an anonymized field in the schema
EctoAnon.Schema lets you define anonymizable fields.
Macro to declare anonymizable fields
Macro to create an anonymized field in the schema